% Filter Demonstration
% JJBA, 4/23/11

%% Get real data signal and define parameters
load('FiveSecondsRealData.mat');  % Has one variable named RealData, 5 seconds of data at 1000 Hz
srate = 256;  % sample rate for real data signal
time_vals = 1/srate:1/srate:(1/srate)*length(RealData); % create time values for x axis

% Show data
figure;
plot(time_vals,RealData);

%% Load alpha filter
load('AlphaFilter256Hz.mat');
alpha_filt = alpha_filt';   % Transpose from column vector to row vector.

% show filter
figure;
plot(time_vals(1:srate+1),alpha_filt);


%% Visual Demonstration of Filter
filtered_signal = plot_filt_in_action(RealData, alpha_filt, time_vals);

%% Generate Other Signals and show how filter works on these
% Alpha
freq = 10;
alpha_wave = sin(2*pi*freq*time_vals);
filtered_signal = plot_filt_in_action(alpha_wave, alpha_filt, time_vals);

%% Theta
freq = 6;
theta_wave = sin(2*pi*freq*time_vals);
figure;
filtered_signal = plot_filt_in_action(theta_wave, alpha_filt, time_vals);
figure; [AX,Y1,Y2]= plotyy(time_vals,theta_wave,time_vals,filtered_signal);  set(Y2,'Color',[1 0 0]);  set(AX(2),'YColor',[1 0 0]); % show on different axis scales -- waveform tiny, but there is a wee bit-o-theta left

%% Delta
freq = 2;
delta_wave = sin(2*pi*freq*time_vals);
figure;
filtered_signal = plot_filt_in_action(delta_wave, alpha_filt, time_vals);
figure; [AX,Y1,Y2]= plotyy(time_vals,delta_wave,time_vals,filtered_signal);  set(Y2,'Color',[1 0 0]); set(AX(2),'YColor',[1 0 0]); % show on different axis scales -- waveform tiny, but there is a wee bit-o-delta left


%% Design a bandpass filter
lowcut = 9;
highcut = 11;
notch = 0;
plot_gain = 1;
filtorder_factor = 1;
[f_weights, f_axis, gain, ideal_actual_corr] = optFIR_design(lowcut, highcut, srate, notch, plot_gain, filtorder_factor);
pause;
% Plot filter coeeficients
figure; plot(f_weights);
pause
filtered_signal = plot_filt_in_action(alpha_wave, alpha_wavelet, time_vals);



%% Compare Matlab's filtfilt to our convolving method

filtered_signal = FIR_filt(RealData,f_weights,1);
filtfilt_filtered_signal = filtfilt(f_weights,1,RealData);
figure;
plot(RealData)
figure;
hold on
plot(filtfilt_filtered_signal,'-r')
plot(filtered_signal,'-g')


